@@ -14,7 +14,6 @@ public:
     QString getFlfiTag();
     QString getFlerTag();
     QString getFlifTag();
-    QString getFlAppIdTag();
     QString getFlCtIdTag();
     QString getAutoSavePath();
 
@@ -23,7 +22,6 @@ public:
     void setFlfiTag(QString newTag);
     void setFlerTag(QString newTag);
     void setFlifTag(QString newTag);
-    void setFlAppIdTag(QString newTag);
     void setFlCtIdTag(QString newTag);
     void setAutoSavePath(QString newTag);
 
@@ -35,7 +33,6 @@ private:
     QString tagFLFI;
     QString tagFLER;
     QString tagFLIF;
-    QString tagFLAppId;
     QString tagFLCtId;
     QString AutoSavePath;
 
