@@ -490,6 +490,6 @@ void FiletransferPlugin::configurationChanged()
 {}
 
 
-#ifndef QT5
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 Q_EXPORT_PLUGIN2(filetransferplugin, FiletransferPlugin)
 #endif
