@@ -35,7 +35,7 @@ class FiletransferPlugin : public QObject, QDLTPluginInterface, QDltPluginViewer
     Q_INTERFACES(QDltPluginViewerInterface)
     Q_INTERFACES(QDltPluginCommandInterface)
     Q_INTERFACES(QDltPluginControlInterface)
-#ifdef QT5
+#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     Q_PLUGIN_METADATA(IID "org.genivi.DLT.FileTransferPlugin")
 #endif
 
