@@ -519,7 +519,7 @@ bool NonverbosePlugin::isMsg(QDltMsg &msg, int triggeredByUser)
 bool NonverbosePlugin::decodeMsg(QDltMsg &msg, int triggeredByUser)
 {
     Q_UNUSED(triggeredByUser)
-    int offset = 4;
+    int offset = 0;
 
     if((msg.getMode() != QDltMsg::DltModeNonVerbose))
     {
@@ -562,6 +562,18 @@ bool NonverbosePlugin::decodeMsg(QDltMsg &msg, int triggeredByUser)
     msg.setSubtype(frame->messageInfo);
     QByteArray payload = msg.getPayload();
 
+    // starting offset depends on DLT protocol version
+    if(msg.getVersionNumber()==2)
+    {
+        // offset is 0, as message id is already in the header
+        offset = 0;
+    }
+    else
+    {
+        // message id is in the payload in the first four bytes
+        offset = 4;
+    }
+
     /* Look for all PDUs for this message */
     for (int i=0;i < frame->pdureflist.size();i++)
     {
@@ -575,7 +587,7 @@ bool NonverbosePlugin::decodeMsg(QDltMsg &msg, int triggeredByUser)
                 argument.setTypeInfo(QDltArgument::DltTypeInfoStrg);
                 argument.setEndianness(msg.getEndianness());
                 argument.setOffsetPayload(offset);
-                data.append(pdu->description);
+                data.append(pdu->description.toUtf8());
                 argument.setData(data);
             }
             else {
@@ -610,6 +622,6 @@ bool NonverbosePlugin::decodeMsg(QDltMsg &msg, int triggeredByUser)
     return true;
 }
 
-#ifndef QT5
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 Q_EXPORT_PLUGIN2(nonverboseplugin, NonverbosePlugin);
 #endif
