@@ -14,7 +14,7 @@
  *
  * \author Alexander Wenzel <alexander.aw.wenzel@bmw.de> 2011-2012
  *
- * \file qdlt.h
+ * \file qdltmsg.h
  * For further information see http://www.covesa.global/.
  * @licence end@
  */
@@ -31,6 +31,8 @@
 #include <time.h>
 
 #include "export_rules.h"
+#include "qdltbase.h"
+#include "qdltargument.h"
 
 //! Access to a DLT message.
 /*!
@@ -69,6 +71,13 @@ public:
     //! The verbose mode of the message.
     typedef enum { DltModeUnknown = -2, DltModeNonVerbose = 0, DltModeVerbose = 1 } DltModeDef;
 
+    //! Get QString from const char id with length of 4 bytes.
+    /*!
+      \param text Pointer to 4 byte id.
+      \return QString of const char text.
+    */
+    static QString getStringFromId(const char *text);
+
     //! Get the time of the DLT message, when the DLT message is logged.
     /*!
       \return The time when the DLT message is logged.
@@ -430,6 +439,17 @@ public:
     */
     bool setMsg(const QByteArray& buf,bool withStorageHeader = true);
 
+    //! Check the message size provided by a byte array containing the DLT message, without parsing the whole message.
+    /*!
+      \param data the buffer containing the DLT messages.
+      \param size the size of the buffer
+      \return the size of the DLT message including storage header if found
+    */
+    quint32 checkMsgSize(const char *data,quint32 size);
+
+    //! Parse the arguments from the Payload.
+    bool parseArguments();
+
     //! Get the message written into a byte array containing the DLT message.
     /*!
       This function returns false, if an error in the data was found.
@@ -453,6 +473,80 @@ public:
       \return The payload string.
     */
     QString toStringPayload() const;
+
+    // Setter and Getters for new DLTv2 parameters
+    uint8_t getVersionNumber() const;
+    void setVersionNumber(uint8_t newVersionNumber);
+
+    bool getWithSessionId() const;
+    void setWithSessionId(bool newWithSessionId);
+
+    bool getWithAppContextId() const;
+    void setWithAppContextId(bool newWithAppContextId);
+
+    bool getWithEcuId() const;
+    void setWithEcuId(bool newWithEcuId);
+
+    quint8 getContentInformation() const;
+    void setContentInformation(quint8 newContentInformation);
+
+    bool getWithHFMessageInfo() const;
+    void setWithHFMessageInfo(bool newWithHFMessageInfo);
+
+    bool getWithHFNumberOfArguments() const;
+    void setWithHFNumberOfArguments(bool newWithHFNumberOfArguments);
+
+    bool getWithHFTimestamp() const;
+    void setWithHFTimestamp(bool newWithHFTimestamp);
+
+    bool getWithHFMessageId() const;
+    void setWithHFMessageId(bool newWithHFMessageId);
+
+    bool getWithSegementation() const;
+    void setWithSegementation(bool newWithSegementation);
+
+    bool getWithPrivacyLevel() const;
+    void setWithPrivacyLevel(bool newWithPrivacyLevel);
+
+    bool getWithTags() const;
+    void setWithTags(bool newWithTags);
+
+    bool getWithSourceFileNameLineNumber() const;
+    void setWithSourceFileNameLineNumber(bool newWithSourceFileNameLineNumber);
+
+    quint32 getTimestampNanoseconds() const;
+    void setTimestampNanoseconds(quint32 newTimestampNanoseconds);
+
+    quint64 getTimestampSeconds() const;
+    void setTimestampSeconds(quint64 newTimestampSeconds);
+
+    const QString &getSourceFileName() const;
+    void setSourceFileName(const QString &newSourceFileName);
+
+    quint32 getLineNumber() const;
+    void setLineNumber(quint32 newLineNumber);
+
+    const QStringList &getTags() const;
+    void setTags(const QStringList &newTags);
+
+    quint8 getPrivacyLevel() const;
+    void setPrivacyLevel(quint8 newPrivacyLevel);
+
+    quint8 getSegmentationFrameType() const;
+    void setSegmentationFrameType(quint8 newSegmentationFrameType);
+
+    quint64 getSegmentationTotalLength() const;
+    void setSegmentationTotalLength(quint64 newSegmentationTotalLength);
+
+    quint32 getSegmentationConsecutiveFrame() const;
+    void setSegmentationConsecutiveFrame(quint32 newSegmentationConsecutiveFrame);
+
+    quint8 getSegmentationAbortReason() const;
+    void setSegmentationAbortReason(quint8 newSegmentationAbortReason);
+
+    int getIndex() const;
+    void setIndex(int newIndex);
+
 protected:
 
 private:
@@ -518,6 +612,41 @@ private:
 
     //! List of arguments of the DLT message.
     QList<QDltArgument> arguments;
+
+    //! New parameters of DLTv2 protocol
+    uint8_t versionNumber;
+    bool withSessionId;
+    bool withAppContextId;
+    bool withEcuId;
+    quint8 contentInformation; // 0x0 = verbose, 0x1 = non verbose, 0x2 = control
+    bool withHFMessageInfo; // verbose or control
+    bool withHFNumberOfArguments; // verbose or control
+    bool withHFTimestamp; // verbose or none verbose
+    bool withHFMessageId; // none verbose
+
+    bool withSegementation;
+    bool withPrivacyLevel;
+    bool withTags;
+    bool withSourceFileNameLineNumber;
+
+    quint32 timestampNanoseconds;
+    quint64 timestampSeconds;
+
+    QString sourceFileName;
+    quint32 lineNumber;
+
+    QStringList tags;
+
+    quint8 privacyLevel;
+
+    quint8 segmentationFrameType;
+    quint64 segmentationTotalLength;
+    quint32 segmentationConsecutiveFrame;
+    quint8 segmentationAbortReason;
+
+    //! Position of current file in a QDltFile
+    int index;
+
 };
 
 #endif // QDLT_MSG_H
