@@ -27,7 +27,9 @@
 
 #include "version.h"
 
-#include "qdlt.h"
+#include "qdltsettingsmanager.h"
+
+#include <ctime>
 
 #if (WIN32)
  #define TZSET _tzset()
@@ -137,7 +139,6 @@ void QDltSettingsManager::writeSettingsLocal(QXmlStreamWriter &xml)
             xml.writeTextElement("autoMarkFatalError",QString("%1").arg(autoMarkFatalError));
             xml.writeTextElement("autoMarkWarn",QString("%1").arg(autoMarkWarn));
             xml.writeTextElement("autoMarkMarker",QString("%1").arg(autoMarkMarker));
-            xml.writeTextElement("writeControl",QString("%1").arg(writeControl));
             xml.writeTextElement("updateContextLoadingFile",QString("%1").arg(updateContextLoadingFile));
             xml.writeTextElement("updateContextsUnregister",QString("%1").arg(updateContextsUnregister));
             xml.writeTextElement("loggingOnlyMode",QString("%1").arg(loggingOnlyMode));
@@ -165,6 +166,7 @@ void QDltSettingsManager::writeSettings()
     settings->setValue("tempdir/tempOwnPath", tempOwnPath);
     settings->setValue("tempdir/tempCloseWithoutAsking", tempCloseWithoutAsking);
     settings->setValue("tempdir/tempSaveOnClear", tempSaveOnClear);
+    settings->setValue("tempdir/tempSaveOnExit", tempSaveOnExit);
 
     /* startup */
     settings->setValue("startup/defaultProjectFile",defaultProjectFile);
@@ -219,7 +221,6 @@ void QDltSettingsManager::writeSettings()
     settings->setValue("startup/showMsgId",showMsgId);
 
     /* other */
-    settings->setValue("startup/writeControl",writeControl);
     settings->setValue("startup/updateContextLoadingFile",updateContextLoadingFile);
     settings->setValue("startup/updateContextsUnregister",updateContextsUnregister);
     settings->setValue("startup/msgIdFormat",msgIdFormat);
@@ -361,10 +362,6 @@ void QDltSettingsManager::readSettingsLocal(QXmlStreamReader &xml)
     {
         markercolor.setNamedColor(xml.readElementText());
     }
-    if(xml.name() == QString("writeControl"))
-    {
-        writeControl = xml.readElementText().toInt();
-    }
     if(xml.name() == QString("updateContextLoadingFile"))
     {
         updateContextLoadingFile = xml.readElementText().toInt();
@@ -406,6 +403,7 @@ void QDltSettingsManager::readSettings()
     tempOwnPath                 = settings->value("tempdir/tempOwnPath", QString("")).toString();
     tempCloseWithoutAsking      = settings->value("tempdir/tempCloseWithoutAsking", 0).toInt();
     tempSaveOnClear             = settings->value("tempdir/tempSaveOnClear", 1).toInt();
+    tempSaveOnExit              = settings->value("tempdir/tempSaveOnExit", 1).toInt();
 
     geometry = settings->value("geometry",0).toByteArray();
     windowState = settings->value("windowState",0).toByteArray();
@@ -433,7 +431,7 @@ void QDltSettingsManager::readSettings()
     autoMarkMarker = settings->value("startup/autoMarkMarker",1).toInt();
     loggingOnlyMode = settings->value("startup/loggingOnlyMode",0).toInt();
     splitlogfile = settings->value("startup/splitfileyesno",0).toInt();
-    fmaxFileSizeMB = settings->value("startup/maxFileSizeMB",0).toFloat();
+    fmaxFileSizeMB = settings->value("startup/maxFileSizeMB",100).toFloat();
     appendDateTime = settings->value("startup/appendDateTime",0).toInt();
     markercolor.setNamedColor(settings->value("startup/markercolor","#aaaaaa").toString() );
 
@@ -469,7 +467,6 @@ void QDltSettingsManager::readSettings()
     showArguments = settings->value("startup/showArguments",0).toInt();
     showMsgId = settings->value("startup/showMsgId",0).toInt();
     /* other */
-    writeControl = settings->value("startup/writeControl",1).toInt();
     updateContextLoadingFile = settings->value("startup/updateContextLoadingFile",1).toInt();
     updateContextsUnregister = settings->value("startup/updateContextsUnregister",0).toInt();
     msgIdFormat = settings->value("startup/msgIdFormat","[%08u]").toString();
