@@ -26,6 +26,7 @@
 #include "project.h"
 #include "dltuiutils.h"
 #include "dlt_user.h"
+#include "qdltoptmanager.h"
 
 
 const char *loginfo[] = {"default","off","fatal","error","warn","info","debug","verbose","","","","","","","","",""};
@@ -74,6 +75,8 @@ EcuItem::EcuItem(QTreeWidgetItem *parent)
     //socket.setReadBufferSize(64000);
 
     autoReconnectTimestamp = QDateTime::currentDateTime();
+
+    writeDLTv2StorageHeader = false;
 }
 
 EcuItem::~EcuItem()
@@ -214,6 +217,16 @@ bool EcuItem::operator< ( const QTreeWidgetItem & other ) const {
     return currentItem.toLower() < otherItem.toLower();
 }
 
+bool EcuItem::getWriteDLTv2StorageHeader() const
+{
+    return writeDLTv2StorageHeader;
+}
+
+void EcuItem::setWriteDLTv2StorageHeader(bool newWriteDLTv2StorageHeader)
+{
+    writeDLTv2StorageHeader = newWriteDLTv2StorageHeader;
+}
+
 bool EcuItem::isAutoReconnectTimeoutPassed()
 {
 
@@ -604,21 +617,21 @@ void PluginItem::update()
             break;
     }
 
-    setText(0, plugin->getName());
+    setText(0, plugin->name());
     setText(1, modeString);
     setText(2, this->getFilename());
 }
 
 QString PluginItem::getName(){
-    return plugin->getName();
+    return plugin->name();
 }
 
 QString PluginItem::getPluginVersion(){
-    return plugin->getPluginVersion();
+    return plugin->pluginVersion();
 }
 
 QString PluginItem::getPluginInterfaceVersion(){
-    return plugin->getPluginInterfaceVersion();
+    return plugin->pluginInterfaceVersion();
 }
 
 QString PluginItem::getFilename(){
@@ -877,6 +890,12 @@ bool Project::Load(QString filename)
                   if(ecuitem)
                       ecuitem->autoReconnectTimeout = xml.readElementText().toInt();
 
+              }
+              if(xml.name() == QString("writeDLTv2StorageHeader"))
+              {
+                  if(ecuitem)
+                      ecuitem->setWriteDLTv2StorageHeader(xml.readElementText().toInt());
+
               }
 
               if(filteritem)
@@ -1063,6 +1082,7 @@ bool Project::Save(QString filename)
         xml.writeTextElement("multicast",QString("%1").arg(ecuitem->is_multicast));
         xml.writeTextElement("autoReconnect",QString("%1").arg(ecuitem->autoReconnect));
         xml.writeTextElement("autoReconnectTimeout",QString("%1").arg(ecuitem->autoReconnectTimeout));
+        xml.writeTextElement("writeDLTv2StorageHeader",QString("%1").arg(ecuitem->getWriteDLTv2StorageHeader()));
 
         for(int numapp = 0; numapp < ecuitem->childCount(); numapp++)
         {
