@@ -20,8 +20,13 @@
 #ifndef PROJECT_H
 #define PROJECT_H
 
+
 #include "qdlt.h"
 #include "plugintreewidget.h"
+#include "qdltipconnection.h"
+#include "qdltserialconnection.h"
+#include "qdltplugin.h"
+#include "qdltsettingsmanager.h"
 
 
 #include <QTreeWidget>
@@ -127,6 +132,7 @@ private:
      unsigned int udpport; /*basically the same*/
      bool sendSerialHeaderIp;
      bool syncSerialHeaderIp;
+     bool writeDLTv2StorageHeader;
 
 public:
      QDltIPConnection ipcon;
@@ -169,7 +175,8 @@ public:
      void setSendSerialHeaderSerial(bool b) {sendSerialHeaderSerial = b;serialcon.setSendSerialHeader(sendSerialHeaderSerial);}
      void setSyncSerialHeaderSerial(bool b) {syncSerialHeaderSerial = b;serialcon.setSyncSerialHeader(syncSerialHeaderSerial);}
 
-
+     bool getWriteDLTv2StorageHeader() const;
+     void setWriteDLTv2StorageHeader(bool newWriteDLTv2StorageHeader);
 };
 
 class ApplicationItem  : public QTreeWidgetItem
