@@ -30,6 +30,7 @@
 #include "ui_settingsdialog.h"
 #include "version.h"
 #include "dltuiutils.h"
+#include "qdltsettingsmanager.h"
 
 
 #if (WIN32)
@@ -222,6 +223,7 @@ void SettingsDialog::writeDlg()
     ui->lineEditOwnTemp->setText(settings->tempOwnPath);
     ui->checkBoxCloseWithoutAsking->setChecked(settings->tempCloseWithoutAsking == 1 ? true : false);
     ui->checkBoxSaveOnClear->setChecked(settings->tempSaveOnClear == 1 ? true : false);
+    ui->checkBoxSaveOnExit->setChecked(settings->tempSaveOnExit == 1 ? true : false);
 
     /* startup */
     ui->checkBoxDefaultProjectFile->setCheckState(settings->defaultProjectFile?Qt::Checked:Qt::Unchecked);
@@ -369,7 +371,6 @@ void SettingsDialog::writeDlg()
     ui->spinBox_showArguments->setValue(settings->showArguments);
 
     /* other */
-    ui->checkBoxWriteControl->setCheckState(settings->writeControl?Qt::Checked:Qt::Unchecked);
     ui->checkBoxUpdateContextLoadingFile->setCheckState(settings->updateContextLoadingFile?Qt::Checked:Qt::Unchecked);
     ui->checkBoxUpdateContextUnregister->setCheckState(settings->updateContextsUnregister?Qt::Checked:Qt::Unchecked);
 
@@ -391,6 +392,7 @@ void SettingsDialog::readDlg()
     settings->tempOwnPath                 = ui->lineEditOwnTemp->text();
     settings->tempCloseWithoutAsking      = (ui->checkBoxCloseWithoutAsking->isChecked() == true ? 1 : 0);
     settings->tempSaveOnClear             = (ui->checkBoxSaveOnClear->isChecked() == true ? 1 : 0);
+    settings->tempSaveOnExit              = (ui->checkBoxSaveOnExit->isChecked() == true ? 1 : 0);
 
     /* startup */
     settings->defaultProjectFile = (ui->checkBoxDefaultProjectFile->checkState() == Qt::Checked);
@@ -456,7 +458,6 @@ void SettingsDialog::readDlg()
     settings->showMsgId     = (ui->groupBoxMessageId->isChecked()==true?1:0);
 
     /* other */
-    settings->writeControl = (ui->checkBoxWriteControl->checkState() == Qt::Checked);
     settings->updateContextLoadingFile = (ui->checkBoxUpdateContextLoadingFile->checkState() == Qt::Checked);
     settings->updateContextsUnregister = (ui->checkBoxUpdateContextUnregister->checkState() == Qt::Checked);
 
@@ -691,11 +692,11 @@ void SettingsDialog::on_checkBoxPluginsAutoload_stateChanged(int activated)
 
 void SettingsDialog::on_pushButtonMarkerColor_clicked()
 {
-    QColor selectedcolor = QColorDialog::getColor( ui->labelSelectedMarkerColor->palette().background().color().name() );
+    QColor selectedcolor = QColorDialog::getColor( ui->labelSelectedMarkerColor->palette().window().color().name() );
     QPalette palette = ui->labelSelectedMarkerColor->palette();
     palette.setColor(QPalette::Active,this->backgroundRole(),selectedcolor);
     palette.setColor(QPalette::Inactive,this->backgroundRole(),QColor(255,255,255,255));
-    palette.setColor(QPalette::Foreground,DltUiUtils::optimalTextColor(selectedcolor));
+    palette.setColor(QPalette::WindowText,DltUiUtils::optimalTextColor(selectedcolor));
     ui->labelSelectedMarkerColor->setPalette(palette);
 
     if(selectedcolor.isValid())
